{% load i18n %}
<div class="failure sequence proctored-exam" data-exam-id="{{exam_id}}">
  <h3>
    {% blocktrans %}
      Error with proctored exam
    {% endblocktrans %}
  </h3>

  <p>
    {% blocktrans %}
      A technical error has occurred with your proctored exam. Please
      reach out to <a href="{{link_urls.contact_us}}" target="_blank">
      edX Support</a> and your course team immediately for assistance.
    {% endblocktrans %}
  </p>
  <p>
    {% blocktrans %}
      Once the error is resolved, you will need to restart the exam
      and answer all questions again. If you have concerns about your
      proctoring session results, please contact your course team.
    {% endblocktrans %}
  </p>
</div>
{% include 'proctored_exam/footer.html' %}
